@@ -15,25 +15,24 @@
 static const char *action = NULL;
 static const char *value  = NULL;
 
-static void __attribute__((noreturn))
-usage(int code)
+static void KBD_ATTR_NORETURN
+usage(int rc, const struct kbd_help *options)
 {
 	fprintf(stderr,
-	        _("Usage: %1$s [options] getmode [text|graphics]\n"
-	          "   or: %1$s [options] gkbmode [raw|xlate|mediumraw|unicode]\n"
-	          "   or: %1$s [options] gkbmeta [metabit|escprefix]\n"
-	          "   or: %1$s [options] gkbled  [scrolllock|numlock|capslock]\n"
-	          "\n"
-	          "The utility allows to read and check various parameters\n"
-	          "of the keyboard and virtual console.\n"
-	          "\n"
-	          "Options:\n"
-	          "  -C, --console=DEV  the console device to be used;\n"
-	          "  -V, --version      print version number;\n"
-	          "  -h, --help         print this usage message.\n"
-	         ),
-	        get_progname());
-	exit(code);
+			_("Usage: %1$s [option...] getmode [text|graphics]\n"
+			  "   or: %1$s [option...] gkbmode [raw|xlate|mediumraw|unicode]\n"
+			  "   or: %1$s [option...] gkbmeta [metabit|escprefix]\n"
+			  "   or: %1$s [option...] gkbled  [scrolllock|numlock|capslock]\n"),
+			program_invocation_short_name);
+	fprintf(stderr, "\n");
+	fprintf(stderr, _(
+				"The utility allows to read and check various parameters\n"
+				"of the keyboard and virtual console.\n"));
+
+	print_options(options);
+	print_report_bugs();
+
+	exit(rc);
 }
 
 static int
@@ -53,6 +52,8 @@ int main(int argc, char **argv)
 	char flags;
 	const char *console = NULL;
 
+	setuplocale();
+
 	const char *short_opts = "C:hV";
 	const struct option long_opts[] = {
 		{ "console", required_argument, NULL, 'C' },
@@ -60,31 +61,34 @@ int main(int argc, char **argv)
 		{ "version", no_argument,       NULL, 'V' },
 		{ NULL,      0,                 NULL,  0  }
 	};
-
-	set_progname(argv[0]);
-	setuplocale();
+	const struct kbd_help opthelp[] = {
+		{ "-C, --console=DEV", _("the console device to be used.") },
+		{ "-V, --version",     _("print version number.")     },
+		{ "-h, --help",        _("print this usage message.") },
+		{ NULL, NULL }
+	};
 
 	while ((c = getopt_long(argc, argv, short_opts, long_opts, NULL)) != -1) {
 		switch (c) {
 			case 'C':
 				if (optarg == NULL || optarg[0] == '\0')
-					usage(EX_USAGE);
+					usage(EX_USAGE, opthelp);
 				console = optarg;
 				break;
 			case 'V':
 				print_version_and_exit();
 				break;
 			case 'h':
-				usage(EXIT_SUCCESS);
+				usage(EXIT_SUCCESS, opthelp);
 				break;
 			case '?':
-				usage(EX_USAGE);
+				usage(EX_USAGE, opthelp);
 				break;
 		}
 	}
 
 	if (optind == argc) {
-		kbd_error(EXIT_FAILURE, 0, _("Error: Not enough arguments.\n"));
+		kbd_error(EXIT_FAILURE, 0, _("Not enough arguments."));
 	}
 
 	action = argv[optind++];
@@ -93,11 +97,11 @@ int main(int argc, char **argv)
 		value = argv[optind++];
 
 	if ((fd = getfd(console)) < 0)
-		kbd_error(EXIT_FAILURE, 0, _("Couldn't get a file descriptor referring to the console"));
+		kbd_error(EXIT_FAILURE, 0, _("Couldn't get a file descriptor referring to the console."));
 
 	if (!strcasecmp("GETMODE", action)) {
 		if (ioctl(fd, KDGETMODE, &mode) == -1)
-			kbd_error(EXIT_FAILURE, errno, "ioctl KDGETMODE");
+			kbd_error(EXIT_FAILURE, errno, _("Unable to read console mode"));
 
 		switch (mode) {
 			case KD_TEXT:
@@ -110,7 +114,7 @@ int main(int argc, char **argv)
 
 	} else if (!strcasecmp("GKBMODE", action)) {
 		if (ioctl(fd, KDGKBMODE, &mode) == -1)
-			kbd_error(EXIT_FAILURE, errno, "ioctl KDGKBMODE");
+			kbd_error(EXIT_FAILURE, errno, _("Unable to read keyboard mode"));
 
 		switch (mode) {
 			case K_RAW:
@@ -129,7 +133,7 @@ int main(int argc, char **argv)
 
 	} else if (!strcasecmp("GKBMETA", action)) {
 		if (ioctl(fd, KDGKBMETA, &mode) == -1)
-			kbd_error(EXIT_FAILURE, errno, "ioctl KDGKBMETA");
+			kbd_error(EXIT_FAILURE, errno, _("Unable to read meta key handling mode"));
 
 		switch (mode) {
 			case K_METABIT:
@@ -142,7 +146,7 @@ int main(int argc, char **argv)
 
 	} else if (!strcasecmp("GKBLED", action)) {
 		if (ioctl(fd, KDGKBLED, &flags) == -1)
-			kbd_error(EXIT_FAILURE, errno, "ioctl KDGKBLED");
+			kbd_error(EXIT_FAILURE, errno, _("Unable to read keyboard flags"));
 
 		mode = (flags & 0x7);
 
@@ -159,7 +163,7 @@ int main(int argc, char **argv)
 		}
 
 	} else {
-		kbd_warning(0, _("Error: Unrecognized action: %s\n"), action);
+		kbd_warning(0, _("Unrecognized argument: %s"), action);
 	}
 
 	close(fd);
