@@ -13,7 +13,6 @@
 
 #include "keymap.h"
 
-#include "libcommon.h"
 #include "contextP.h"
 #include "ksyms.h"
 #include "modifiers.h"
@@ -58,9 +57,6 @@ int lk_get_kmapinfo(struct lk_ctx *ctx, struct kmapinfo *res)
 {
 	int i;
 
-	if (!ctx)
-		return -1;
-
 	res->flags     = ctx->flags;
 	res->keywords  = ctx->keywords;
 	res->keymaps   = ctx->keymap->count;
