@@ -1,6 +1,8 @@
 /*
  * totextmode.c - aeb - 2000-01-20
  */
+#include "config.h"
+
 #include <stdlib.h>
 #include <sys/types.h>
 #include <sys/ioctl.h>
@@ -9,30 +11,26 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <fcntl.h>
-#include "getfd.h"
-#include "nls.h"
-#include "version.h"
-#include "kbd_error.h"
 
-int
-main(int argc, char *argv[]) {
-	int fd, num;
+#include "libcommon.h"
 
-	set_progname(argv[0]);
+int main(int argc, char *argv[])
+{
+	int fd;
 
-	setlocale(LC_ALL, "");
-	bindtextdomain(PACKAGE_NAME, LOCALEDIR);
-	textdomain(PACKAGE_NAME);
+	setuplocale();
 
 	if (argc == 2 && !strcmp(argv[1], "-V"))
 		print_version_and_exit();
 
 	if (argc != 2) {
-		kbd_error(EXIT_FAILURE, 0, _("usage: totextmode\n"));
+		kbd_error(EXIT_FAILURE, 0, _("Usage: %s [option...]\n"), program_invocation_short_name);
 	}
-	fd = getfd(NULL);
-	num = atoi(argv[1]);
-	if (ioctl(fd,KDSETMODE,KD_TEXT)) {
+
+	if ((fd = getfd(NULL)) < 0)
+		kbd_error(EXIT_FAILURE, 0, _("Couldn't get a file descriptor referring to the console."));
+
+	if (ioctl(fd, KDSETMODE, KD_TEXT)) {
 		kbd_error(EXIT_FAILURE, errno, "totextmode: KDSETMODE");
 	}
 	return EXIT_SUCCESS;
