@@ -26,10 +26,11 @@
 #include <stdlib.h>
 #include <errno.h>
 #include <getopt.h>
+#include <sysexits.h>
 
 #include "vlock.h"
-#include "nls.h"
-#include "version.h"
+
+#include "libcommon.h"
 
 /*
  * This determines whether the default behavior is to lock only the
@@ -44,16 +45,16 @@ locked_name(void)
 	return o_lock_all ? "console" : (is_vt ? "VC" : "tty");
 }
 
-static void __attribute__((__noreturn__))
+static void KBD_ATTR_NORETURN
 show_usage(void)
 {
 	fprintf(stderr,
 	        _("Try `%s --help' for more information.\n"),
 	        program_invocation_short_name);
-	exit(1);
+	exit(EX_USAGE);
 }
 
-static void __attribute__((__noreturn__))
+static void KBD_ATTR_NORETURN
 show_help(void)
 {
 	printf(_("%s: locks virtual consoles, saving your current session.\n"
@@ -65,22 +66,22 @@ show_help(void)
 	         "       from switching virtual consoles.\n"
 	         "-v or --version: Print the version number of vlock and exit.\n"
 	         "-h or --help: Print this help message and exit.\n"),
-	       progname, progname);
+	       program_invocation_short_name, program_invocation_short_name);
 	exit(0);
 }
 
 void parse(int ac, char *const av[])
 {
 	static struct option long_options[] = {
-		{ "current", 0, 0, 'c' },
-		{ "all", 0, 0, 'a' },
-		{ "version", 0, 0, 'v' },
-		{ "help", 0, 0, 'h' },
-		{ 0, 0, 0, 0 },
+		{ "current", 0, NULL, 'c' },
+		{ "all", 0, NULL, 'a' },
+		{ "version", 0, NULL, 'v' },
+		{ "help", 0, NULL, 'h' },
+		{ NULL, 0, NULL, 0 },
 	};
 	int c;
 
-	while ((c = getopt_long(ac, av, "acvh", long_options, 0)) != -1) {
+	while ((c = getopt_long(ac, av, "acvh", long_options, NULL)) != -1) {
 		switch (c) {
 			case 'c':
 				o_lock_all = 0;
