@@ -7,15 +7,13 @@
 #include "libcommon.h"
 
 int
-main(int __attribute__((unused)) argc, char **argv)
+main(int argc KBD_ATTR_UNUSED, char **argv KBD_ATTR_UNUSED)
 {
-	set_progname(argv[0]);
-
-	struct kbdfile *fp = kbdfile_open(NULL, DATADIR "/data/findfile/test_0/keymaps/i386/qwerty/test0.map");
+	struct kbdfile *fp = kbdfile_open(NULL, TESTDIR "/data/findfile/test_0/keymaps/i386/qwerty/test0.map");
 	if (!fp)
 		kbd_error(EXIT_FAILURE, 0, "unable to create kbdfile");
 
-	const char *expect = DATADIR "/data/findfile/test_0/keymaps/i386/qwerty/test0.map";
+	const char *expect = TESTDIR "/data/findfile/test_0/keymaps/i386/qwerty/test0.map";
 	if (strcmp(expect, kbdfile_get_pathname(fp)) != 0)
 		kbd_error(EXIT_FAILURE, 0, "unexpected file: %s (expected %s)", kbdfile_get_pathname(fp), expect);
 
