@@ -19,7 +19,7 @@ main(int argc KBD_ATTR_UNUSED, char **argv KBD_ATTR_UNUSED)
 		/* Find,    Insert,     Remove,     Select,     Prior */
 		"\033[1~", "\033[2~", "\033[3~", "\033[4~", "\033[5~",
 		/* Next,    Macro,      Help,       Do,         Pause */
-		"\033[6~", 0, 0, 0, 0
+		"\033[6~", NULL, NULL, NULL, NULL
 	};
 	unsigned int i;
 	struct lk_ctx *ctx;
@@ -36,7 +36,7 @@ main(int argc KBD_ATTR_UNUSED, char **argv KBD_ATTR_UNUSED)
 		strncpy((char *)ke.kb_string, stringvalues[i],
 		        sizeof(ke.kb_string));
 		ke.kb_string[sizeof(ke.kb_string) - 1] = 0;
-		ke.kb_func                             = (unsigned char) i;
+		ke.kb_func = (unsigned char) i;
 
 		if (lk_add_func(ctx, &ke) == -1)
 			kbd_error(EXIT_FAILURE, 0, "Unable to add function");
